@@ -24,6 +24,7 @@ The most commonly used commands are:
     simple_check            check updating modules simply
     check_refinancing       check refinancing info
     check_refinancing_impl  check refinancing implementation info
+    check_untreated_funds   check untreated new funds weekly
     pull_hedge_fund_nav     pull updated navs of hedge funds
 '''
 
@@ -113,6 +114,15 @@ class SurfingEntrance(object):
         basic_data_processor = BasicDataProcessor()
         return basic_data_processor.process_all(yesterday, yesterday), basic_data_processor.get_updated_count()
 
+    def update_basic_not_trading_day(self, yesterday=None):
+        if not yesterday:
+            yesterday = self._get_yesterday()
+
+        from .data.fund.basic.basic_data_processor import BasicDataProcessor
+
+        basic_data_processor = BasicDataProcessor()
+        return basic_data_processor.process_not_trading_day(yesterday, yesterday), basic_data_processor.get_updated_count()
+
     def update_derived(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
@@ -121,6 +131,14 @@ class SurfingEntrance(object):
         derived_data_processor = DerivedDataProcessor()
         return derived_data_processor.process_all(yesterday, yesterday), derived_data_processor.get_updated_count()
 
+    def update_derived_not_trading_day(self, yesterday=None):
+        if not yesterday:
+            yesterday = self._get_yesterday()
+
+        from .data.fund.derived.derived_data_processor import DerivedDataProcessor
+        derived_data_processor = DerivedDataProcessor()
+        return derived_data_processor.process_not_trading_day(yesterday, yesterday), derived_data_processor.get_updated_count()
+
     def update_view(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
@@ -166,15 +184,39 @@ class SurfingEntrance(object):
 
         print('Step 1. Start raw data download')
         raw_failed_tasks, raw_updated_count = self.download_raw(yesterday)
-        if 'em_tradedates' in raw_failed_tasks:
-            print('Step 1. No raw data to download')
-            print(f'Done data update, {yesterday} is not trading day')
-            return
         if len(raw_failed_tasks) > 0:
             failed_tasks['raw'] = raw_failed_tasks
         updated_count['raw'] = raw_updated_count
         print('Step 1. Done raw data download')
 
+        if 'em_tradedates' in raw_failed_tasks:
+
+            print('Step 2. Not tradingday day, basic data to download')
+            basic_failed_tasks, basic_updated_count = self.update_basic_not_trading_day(yesterday)
+            if len(basic_failed_tasks) > 0:
+                failed_tasks['basic'] = basic_failed_tasks
+            updated_count['basic'] = basic_updated_count
+            print('Step 2. Done update basic')
+
+            print('Step 3. Not trading day, derived data to calculate')
+            derived_failed_tasks, derived_updated_count = self.update_derived_not_trading_day(yesterday)
+            if len(derived_failed_tasks) > 0:
+                failed_tasks['derived'] = derived_failed_tasks
+            updated_count['derived'] = derived_updated_count
+            print('Step 3. Done update derived')
+
+            print('Done data update')
+            print(f'Failed tasks:\n{failed_tasks}')
+            print(f'Updated count:\n{updated_count}')
+
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+            del failed_tasks['raw'][failed_tasks['raw'].index('em_tradedates')]
+            if not failed_tasks['raw']:
+                del failed_tasks['raw']
+            wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
+            return
+
         print('Step 2. Start update basic')
         basic_failed_tasks, basic_updated_count = self.update_basic(yesterday)
         if len(basic_failed_tasks) > 0:
@@ -218,8 +260,13 @@ class SurfingEntrance(object):
         print('start to update fund factor')
         self.update_fund_factor(yesterday, wechat_bot)
         print('update stock factor done')
+        print('start to check refinancing info')
         self.check_refinancing(yesterday, wechat_bot)
         self.check_refinancing_impl(yesterday, wechat_bot)
+        print('check refinancing info done')
+        print('start to check untreated new funds')
+        self.check_untreated_funds(yesterday, wechat_bot)
+        print('check untreated new funds done')
 
     def calc_fund_estimated_nav(self):
         # Use Jenkins to call this function every hour
@@ -367,8 +414,11 @@ class SurfingEntrance(object):
                 return False
 
     def check_fund_list(self, yesterday=None, wechat_bot=None):
+        from sqlalchemy.orm import sessionmaker
         from .data.fund.raw.raw_data_helper import RawDataHelper
         from .data.api.raw import RawDataApi
+        from .data.wrapper.mysql import BasicDatabaseConnector
+        from .data.view.basic_models import FundInfo
 
         if yesterday is None:
             yesterday = self._get_yesterday()
@@ -379,6 +429,29 @@ class SurfingEntrance(object):
         new_delisted_funds_with_name = {}
         new_funds, new_delisted_funds = RawDataHelper.get_new_and_delisted_fund_list(yesterday)
         if new_funds is not None and new_delisted_funds is not None:
+            if new_delisted_funds:
+                # 如果存在新摘牌的基金 修改一下 basic.fund_info 相应基金的 end_date
+                em_fund_info = RawDataApi().get_em_fund_info(new_delisted_funds)
+                assert em_fund_info is not None and not em_fund_info.empty, f'failed to get em fund info for {new_delisted_funds}'
+                em_fund_info = em_fund_info[['em_id', 'end_date']]
+                em_fund_info = em_fund_info.set_index('em_id')
+
+                fund_ids_succeed_to_set = []
+                Session = sessionmaker(BasicDatabaseConnector().get_engine())
+                db_session = Session()
+                for row in db_session.query(FundInfo).filter(FundInfo.wind_id.in_(new_delisted_funds)).all():
+                    try:
+                        row.end_date = em_fund_info.at[row.wind_id, 'end_date']
+                        fund_ids_succeed_to_set.append(row.wind_id)
+                    except KeyError:
+                        pass
+                db_session.commit()
+                db_session.close()
+
+                fund_ids_failed_to_set = list(set(new_delisted_funds) - set(fund_ids_succeed_to_set))
+                if fund_ids_failed_to_set:
+                    wechat_bot.send_fund_list_that_set_end_date_failed(yesterday, fund_ids_failed_to_set)
+
             # 获取新增基金以及新摘牌基金列表
             agg_funds = new_funds.union(new_delisted_funds)
             if agg_funds:
@@ -603,11 +676,59 @@ class SurfingEntrance(object):
 
             wechat_bot.send_refinancing_impl_key_info(yesterday, stock_info.to_markdown(), key)
 
+    def check_untreated_funds(self, yesterday=None, wechat_bot=None):
+        import pandas as pd
+        from .data.api.raw import RawDataApi
+        from .data.api.basic import BasicDataApi
+
+        if yesterday is None:
+            yesterday = self._get_yesterday()
+
+        # 获取下一个交易日
+        trading_day_df = BasicDataApi().get_trading_day_list(start_date=yesterday)
+        if trading_day_df.shape[0] <= 1:
+            print(f'[check_untreated_funds] get trading days start with {yesterday} failed')
+            return
+        next_trading_day = trading_day_df.iloc[1, :].datetime
+        print(f'[check_untreated_funds] got next trading day {next_trading_day}')
+        end_date_dt = pd.to_datetime(yesterday, infer_datetime_format=True).date()
+        next_trading_dt = pd.to_datetime(next_trading_day, infer_datetime_format=True).date()
+        if end_date_dt.weekday() < next_trading_dt.weekday() and next_trading_dt < end_date_dt + datetime.timedelta(weeks=1):
+            print(f'[check_untreated_funds] only check on the last day of week, not today {end_date_dt}')
+            return
+
+        fund_list = RawDataApi().get_em_fund_list(yesterday, limit=6)
+        if fund_list is None:
+            print(f'[check_untreated_funds] failed to get em fund list, (date){yesterday}')
+            return
+
+        latest_list = fund_list.iloc[0, :]
+        latest_week = pd.to_datetime(latest_list.datetime, infer_datetime_format=True).week
+        for row in fund_list.iloc[1:, :].itertuples(index=False):
+            if pd.to_datetime(row.datetime, infer_datetime_format=True).week != latest_week:
+                base_list = row.all_live_fund_list
+                break
+        else:
+            print(f'[check_untreated_funds] can not find the base fund list (date){yesterday}')
+            return
+
+        untreated_new_funds = set(latest_list.all_live_fund_list.split(',')).difference(set(base_list.split(',')))
+        fund_info = BasicDataApi().get_fund_info()
+        untreated_new_funds = untreated_new_funds.difference(set(fund_info.wind_id.array))
+
+        if wechat_bot is None:
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+
+        wechat_bot.send_untreated_new_fund_list(yesterday, untreated_new_funds)
+
     def pull_hedge_fund_nav(self):
         from .data.manager.manager_fof import FOFDataManager
 
+        FOF_ID = 'SLW695'
+
         fof_dm = FOFDataManager()
-        fof_dm.pull_hedge_fund_nav()
+        fof_dm.pull_hedge_fund_nav(fof_id=FOF_ID)
 
 
 if __name__ == "__main__":
