@@ -1435,8 +1435,9 @@ class BasicDataApi(metaclass=Singleton):
         except Exception as e:
             print(f'failed to get_fof_transit_money <err_msg> {e} from {AssetInfo.__tablename__}')
 
-    def get_asset_price(self, asset_list: Tuple[str] = ()):
+    def get_asset_price(self, begin_date, end_date, time_para, asset_list: Tuple[str] = ()):
         try:
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
             raw = RawDataApi()
             asset_info = self.get_asset_info(asset_id_list=asset_list)
             asset_list = asset_info.asset_id.tolist()
@@ -1464,27 +1465,27 @@ class BasicDataApi(metaclass=Singleton):
             result = []
             if len(_asset_list_0) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_0]
-                _df = raw.get_em_macroeconomic_daily(codes=real_ids,).pivot_table(index='datetime',columns='codes',values='value')
+                _df = raw.get_em_macroeconomic_daily(codes=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='codes',values='value')
                 result.append(_df)
             if len(_asset_list_1) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_1]
-                _df = raw.get_btc(asset_ids=real_ids).pivot_table(index='date',columns='codes',values='close')
+                _df = raw.get_btc(asset_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='date',columns='codes',values='close')
                 result.append(_df)
             if len(_asset_list_2) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_2]
-                _df = raw.get_em_future_price(future_ids=real_ids).pivot_table(index='datetime',columns='future_id',values='close')
+                _df = raw.get_em_future_price(future_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='future_id',values='close')
                 result.append(_df)
             if len(_asset_list_3) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = raw.get_hf_fund_nav(fund_ids=real_ids).pivot_table(index='datetime',columns='fund_id',values='nav')
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
             if len(_asset_list_4) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_4]
-                _df = raw.get_hf_index_price(index_ids=real_ids).pivot_table(index='index_date',columns='index_id',values='close')
+                _df = raw.get_hf_index_price(index_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='index_date',columns='index_id',values='close')
                 result.append(_df)
             if len(_asset_list_5) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_5]
-                _df = self.get_index_price(index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
+                _df = self.get_index_price_dt(index_list=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='index_id',values='close')
                 result.append(_df)
 
             df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
@@ -1498,84 +1499,60 @@ class BasicDataApi(metaclass=Singleton):
         except Exception as e:
                 print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
 
-    def get_product_price(self, product_id_list: Tuple[str] = ()):
+    def get_product_price(self, begin_date, end_date, time_para, product_list: Tuple[str] = (),):
+        try:
+            begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+            raw = RawDataApi()
+            asset_info = self.get_asset_info_real(real_id_list=product_list)
+            asset_info = asset_info.drop_duplicates('real_id')
+            asset_id_list = asset_info.asset_type.unique().tolist()
+            name_dic = asset_info.set_index('real_id').to_dict()['real_name']
+            asset_dic = {}
+            for asset_id in asset_id_list:
+                _df = asset_info[asset_info.asset_type == asset_id]
+                asset_dic[asset_id] = _df.real_id.tolist()
+            result = []
+            if len(asset_dic['典型产品']) > 0:
+                real_ids = asset_dic['典型产品']
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
+                result.append(_df)
+            if '大类资产' in asset_dic.keys():
+                real_ids = asset_dic['大类资产']
+                if len(real_ids) > 0:
+                    _df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
+                    result.append(_df)
+                
+            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
+            df_result = df_result / df_result.iloc[0]
+            df_result = df_result.rename(columns=name_dic)
+            dic = {'data':df_result,'_input_asset_nav':df_result,'_input_asset_info':asset_info}
+            return dic
+        
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_product_price')
+
+    def product_recent_rate(self, product_list, year:int=None):
         try:
             raw = RawDataApi()
-            asset_info = self.get_asset_info_real(real_id_list=product_id_list)
-            asset_list = asset_info.asset_id.tolist()
-            _asset_list = [i for i in asset_list if i.split('-')[0] == 'fund']
-            _res = []
-            for r in asset_info.itertuples():
-                if r.asset_id in _asset_list:
-                    _res.append(r.real_name)
-                else:
-                    _res.append(r.asset_name)
-            asset_info.loc[:,'show_name'] = _res
-            inputs_asset_list = asset_info.asset_id.tolist()
-            asset_dic = asset_info.set_index('asset_id').to_dict()['real_id']
-            asset_list_0 = ['asset-dollar']
-            asset_list_1 = ['asset-btc']
-            asset_list_2 = ['asset-usdebt']
-            _asset_list_0 = [i for i in inputs_asset_list if i in asset_list_0]
-            _asset_list_1 = [i for i in inputs_asset_list if i in asset_list_1]
-            _asset_list_2 = [i for i in inputs_asset_list if i in asset_list_2]
-            _asset_list_3 = [i for i in inputs_asset_list if i.split('-')[0] == 'fund']
-            _asset_list_4 = [i for i in inputs_asset_list if i.split('-')[0] == 'stgindex']
-            _asset_sum = _asset_list_0 + _asset_list_1 + _asset_list_2 + _asset_list_3 + _asset_list_4
-            _asset_list_5 = [i for i in inputs_asset_list if i not in _asset_sum]
-
+            asset_info = self.get_asset_info_real(real_id_list=product_list)
+            asset_info = asset_info.drop_duplicates('real_id')
+            asset_id_list = asset_info.asset_type.unique().tolist()
+            name_dic = asset_info.set_index('real_id').to_dict()['real_name']
+            asset_dic = {}
+            for asset_id in asset_id_list:
+                _df = asset_info[asset_info.asset_type == asset_id]
+                asset_dic[asset_id] = _df.real_id.tolist()
             result = []
-            if len(_asset_list_0) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_0]
-                _df = raw.get_em_macroeconomic_daily(codes=real_ids,).pivot_table(index='datetime',columns='codes',values='value')
+            if len(asset_dic['典型产品']) > 0:
+                real_ids = asset_dic['典型产品']
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids,start_date='20091231').pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
-            if len(_asset_list_1) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_1]
-                _df = raw.get_btc(asset_ids=real_ids).pivot_table(index='date',columns='codes',values='close')
-                result.append(_df)
-            if len(_asset_list_2) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_2]
-                _df = raw.get_em_future_price(future_ids=real_ids).pivot_table(index='datetime',columns='future_id',values='close')
-                result.append(_df)
-            if len(_asset_list_3) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = raw.get_hf_fund_nav(fund_ids=real_ids).pivot_table(index='datetime',columns='fund_id',values='nav')
-                result.append(_df)
-            if len(_asset_list_4) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_4]
-                _df = raw.get_hf_index_price(index_ids=real_ids).pivot_table(index='index_date',columns='index_id',values='close')
-                result.append(_df)
-            if len(_asset_list_5) > 0:
-                real_ids = [asset_dic[i] for i in _asset_list_5]
-                _df = self.get_index_price(index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
-                result.append(_df)
-
-            df_result = pd.concat(result,axis=1).sort_index().ffill().dropna()
-            df_result = df_result / df_result.iloc[0]
-            df_result_show = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['show_name'])
-            df_result_real = df_result.rename(columns=asset_info.set_index('real_id').to_dict()['real_name'])
-            asset_info = asset_info.drop_duplicates(subset=['real_id'])
-            dic = {'data':df_result_show,'_input_asset_nav':df_result_real,'_input_asset_info':asset_info}
-            return dic
-        
-        except Exception as e:
-                print(f'failed to asset price <err_msg> {e} from basic.get_asset_price')
-
-
-    def data_resample_monthly_nav(self, df, rule='1M'):
-        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
-        df.index = [i.date() for i in df.index]
-        df.index.name = 'datetime'
-        return df
-
-    def asset_recent_rate(self, year:int=None):
-        #如果year为空 返回年度收益
-        #如果year为整数 返回当年月度收益 year从2010开始
-        try:
-            index_list = ['hs300','sse','gem','sme','sse50','csi500','csi800','szse_a']
-            index_info = self.get_index_info(index_list=index_list)
-            desc_name_dic = index_info.set_index('index_id').to_dict()['desc_name']
-            index_price = self.get_index_price_dt(start_date='20091231',index_list=index_list).pivot_table(index='datetime',columns='index_id',values='close')
+            if '大类资产' in asset_dic.keys():
+                real_ids = asset_dic['大类资产']
+                if len(real_ids) > 0:
+                    _df = self.get_index_price_dt(start_date='20091231',index_list=real_ids).pivot_table(index='datetime',columns='index_id',values='close')
+                    result.append(_df)
+            index_price = pd.concat(result,axis=1).sort_index().ffill().dropna()
             if year is None:
                 # 年度
                 index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
@@ -1593,8 +1570,97 @@ class BasicDataApi(metaclass=Singleton):
             index_ret.index = td
             index_ret.loc['均值',:] = index_ret.mean()
             index_ret = index_ret.round(4)*100
-            index_ret = index_ret.rename(columns=desc_name_dic)
-            return index_ret.T
+            index_ret = index_ret.rename(columns=name_dic)
+            index_ret = index_ret.T
+            index_ret.index.name = 'index_id'
+            return index_ret
+        except Exception as e:
+                print(f'failed to asset price <err_msg> {e} from basic.get_product_recent_price')
+
+    def data_resample_monthly_nav(self, df, rule='1M'):
+        df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
+        df.index = [i.date() for i in df.index]
+        df.index.name = 'datetime'
+        return df
+
+    def asset_recent_rate(self, asset_list, year:int=None):
+        #如果year为空 返回年度收益
+        #如果year为整数 返回当年月度收益 year从2010开始
+        try:
+            raw = RawDataApi()
+            asset_info = self.get_asset_info(asset_id_list=asset_list)
+            asset_list = asset_info.asset_id.tolist()
+            _asset_list = [i for i in asset_list if i.split('-')[0] == 'fund']
+            _res = []
+            for r in asset_info.itertuples():
+                if r.asset_id in _asset_list:
+                    _res.append(r.real_name)
+                else:
+                    _res.append(r.asset_name)
+            asset_info.loc[:,'show_name'] = _res
+            inputs_asset_list = asset_info.asset_id.tolist()
+            asset_dic = asset_info.set_index('asset_id').to_dict()['real_id']
+            name_dic = asset_info.set_index('real_id').to_dict()['real_name']
+            name_dic = {k : v.replace('CFCI','指数')for k, v in name_dic.items()}
+            asset_list_0 = ['asset-dollar']
+            asset_list_1 = ['asset-btc']
+            asset_list_2 = ['asset-usdebt']
+            _asset_list_0 = [i for i in inputs_asset_list if i in asset_list_0]
+            _asset_list_1 = [i for i in inputs_asset_list if i in asset_list_1]
+            _asset_list_2 = [i for i in inputs_asset_list if i in asset_list_2]
+            _asset_list_3 = [i for i in inputs_asset_list if i.split('-')[0] == 'fund']
+            _asset_list_4 = [i for i in inputs_asset_list if i.split('-')[0] == 'stgindex']
+            _asset_sum = _asset_list_0 + _asset_list_1 + _asset_list_2 + _asset_list_3 + _asset_list_4
+            _asset_list_5 = [i for i in inputs_asset_list if i not in _asset_sum]
+
+            result = []
+            if len(_asset_list_0) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_0]
+                _df = raw.get_em_macroeconomic_daily(codes=real_ids,start_date='20091231').pivot_table(index='datetime',columns='codes',values='value')
+                result.append(_df)
+            if len(_asset_list_1) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_1]
+                _df = raw.get_btc(asset_ids=real_ids,start_date='20091231').pivot_table(index='date',columns='codes',values='close')
+                result.append(_df)
+            if len(_asset_list_2) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_2]
+                _df = raw.get_em_future_price(future_ids=real_ids,start_date='20091231').pivot_table(index='datetime',columns='future_id',values='close')
+                result.append(_df)
+            if len(_asset_list_3) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_3]
+                _df = raw.get_hf_fund_nav(fund_ids=real_ids,start_date='20091231').pivot_table(index='datetime',columns='fund_id',values='nav')
+                result.append(_df)
+            if len(_asset_list_4) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_4]
+                _df = raw.get_hf_index_price(index_ids=real_ids,start_date='20091231').pivot_table(index='index_date',columns='index_id',values='close')
+                result.append(_df)
+            if len(_asset_list_5) > 0:
+                real_ids = [asset_dic[i] for i in _asset_list_5]
+                _df = self.get_index_price_dt(index_list=real_ids,start_date='20091231').pivot_table(index='datetime',columns='index_id',values='close')
+                result.append(_df)
+
+            index_price = pd.concat(result,axis=1).sort_index().ffill().dropna().rename(columns=name_dic)
+            if year is None:
+                # 年度
+                index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
+                index_ret_year = index_price_y.pct_change(1).dropna()
+                td = index_ret_year.index
+                td = [str(i.year) for i in td]
+                index_ret = index_ret_year.copy()
+            else:
+                index_price_m = index_price.loc[datetime.date(year-1,12,31):datetime.date(year,12,31)]
+                index_price_m = self.data_resample_monthly_nav(index_price_m,rule='1M').bfill()
+                index_ret_m = index_price_m.pct_change(1).dropna()
+                td = index_ret_m.index
+                td = [str(i.year) + str(i.month).zfill(2) for i in td ]
+                index_ret = index_ret_m.copy()
+            index_ret.index = td
+            index_ret.loc['均值',:] = index_ret.mean()
+            index_ret = index_ret.round(4)*100
+            #index_ret = index_ret.rename(columns=desc_name_dic)
+            index_ret = index_ret.T
+            index_ret.index.name = 'index_id'
+            return index_ret
 
         except Exception as e:
                 print(f'failed to asset price <err_msg> {e} from basic.asset_recent_rate')
@@ -1669,7 +1735,7 @@ class BasicDataApi(metaclass=Singleton):
         except Exception as e:
                 print(f'failed to asset price <err_msg> {e} from basic.get_main_index_future_diff_yearly')
     
-    def get_indus_info_list(self):
+    def get_industry_list(self):
         try:
             df = RawDataApi().get_em_industry_info(ind_class_type=1)[['em_id','ind_name']]
             em_id_list = df.em_id.to_list()
@@ -1680,12 +1746,12 @@ class BasicDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from get_em_industry_info')
             return []
 
-    def get_industry_price(self, begin_date, end_date, time_para, index_list):
+    def get_industry_price(self, begin_date, end_date, time_para, industry_list):
         try:
             begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
-            df_info = self.get_index_info(index_list)
+            df_info = self.get_index_info(industry_list)
             info_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
-            df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=index_list)
+            df = self.get_index_price_dt(start_date=begin_date,end_date=end_date,index_list=industry_list)
             df = df.pivot_table(columns='index_id',values='close',index='datetime')
             df = df / df.iloc[0]
             df = df.rename(columns=info_dic)
@@ -1695,11 +1761,11 @@ class BasicDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from get_industry_price')
             return pd.DataFrame([])
 
-    def get_industry_recent_ret(self, index_list, year:int=None):
+    def industry_recent_rate(self, industry_list, year:int=None):
         try:
-            df_info = self.get_index_info(index_list)
+            df_info = self.get_index_info(industry_list)
             desc_name_dic = {r.index_id : r.desc_name.replace('(申万)','') for r in df_info.itertuples()}
-            index_price = self.get_index_price_dt(start_date='20091231',index_list=index_list).pivot_table(index='datetime',columns='index_id',values='close')
+            index_price = self.get_index_price_dt(start_date='20091231',index_list=industry_list).pivot_table(index='datetime',columns='index_id',values='close')
             if year is None:
                 # 年度
                 index_price_y = self.data_resample_monthly_nav(index_price.bfill(),rule='12M')
