@@ -7,6 +7,7 @@ from sqlalchemy import func
 
 from ...util.singleton import Singleton
 from ..wrapper.mysql import DerivedDatabaseConnector
+from .raw import RawDataApi
 from ..view.derived_models import *
 
 
@@ -210,6 +211,21 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
+    def delete_index_valuation(self, date_to_delete: datetime.date, index_id_list: List[str]) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    IndexValuationLongTerm
+                ).filter(
+                    IndexValuationLongTerm.index_id.in_(index_id_list),
+                    IndexValuationLongTerm.datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
+                return False
+
     def get_asset_allocation_info(self, version:int=2):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -589,6 +605,20 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFNav.__tablename__}')
                 return False
 
+    def get_fof_nav_public(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FOFNavPublic,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFNavPublic.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_nav_public <err_msg> {e} from {FOFNavPublic.__tablename__}')
+
     def get_fof_position(self, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
@@ -632,7 +662,7 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_investor_data <err_msg> {e} from {FOFInvestorData.__tablename__}')
 
-    def delete_fof_investor_data(self, fof_id_to_delete: datetime.date, investor_id_list: List[str]) -> bool:
+    def delete_fof_investor_data(self, fof_id_to_delete: str, investor_id_list: List[str]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
@@ -661,7 +691,7 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_position_detail <err_msg> {e} from {FOFPositionDetail.__tablename__}')
 
-    def delete_fof_position_detail(self, fof_id_to_delete: datetime.date, fund_id_list: List[str]) -> bool:
+    def delete_fof_position_detail(self, fof_id_to_delete: str, fund_id_list: List[str]) -> bool:
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 session.query(
@@ -674,4 +704,97 @@ class DerivedDataApi(metaclass=Singleton):
                 return True
             except Exception as e:
                 print(f'failed to delete data <err_msg> {e} from {FOFPositionDetail.__tablename__}')
-                return False
\ No newline at end of file
+                return False
+
+    def get_hedge_fund_investor_pur_redemp(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    HedgeFundInvestorPurAndRedemp,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        HedgeFundInvestorPurAndRedemp.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
+
+    def get_hedge_fund_investor_pur_redemp_by_id(self, id: int):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    HedgeFundInvestorPurAndRedemp,
+                ).filter(
+                    HedgeFundInvestorPurAndRedemp.id == id,
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
+
+    def delete_hedge_fund_investor_pur_redemp(self, id_to_delete: int) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    HedgeFundInvestorPurAndRedemp
+                ).filter(
+                    HedgeFundInvestorPurAndRedemp.id == id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
+                return False
+
+    def get_hedge_fund_investor_div_carry(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    HedgeFundInvestorDivAndCarry,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        HedgeFundInvestorDivAndCarry.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_position_detail <err_msg> {e} from {HedgeFundInvestorDivAndCarry.__tablename__}')
+
+    def delete_hedge_fund_investor_div_carry(self, id_to_delete: int) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    HedgeFundInvestorDivAndCarry
+                ).filter(
+                    HedgeFundInvestorDivAndCarry.id == id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {HedgeFundInvestorDivAndCarry.__tablename__}')
+                return False
+
+    def get_style_factor_ret(self, begin_date, end_date, index_list=['hs300']):
+        try:
+            if begin_date is None or end_date is None:
+                time_para = 'YTD'
+            else:
+                time_para = None
+            start_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
+            df = self.get_style_factor_return(start_date, end_date, [index_list])
+            dic = {
+                'latest_size':'规模',
+                'bp':'价值',
+                'short_term_momentum':'短期动量',
+                'long_term_momentum':'长期动量',
+                'high_low':'波动率',
+            }
+            df = df.set_index('datetime')[['latest_size','bp','short_term_momentum','long_term_momentum','high_low','const']]
+            df = df[list(dic.keys())].rename(columns=dic)
+            df = (df+1).cumprod()
+            df = df/df.iloc[0] - 1
+            df.index.name = 'datetime'
+            return df
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.get_style_factor_ret')
+            return False
\ No newline at end of file
