@@ -36,6 +36,14 @@ class OverseaFundNavAnalysis:
         '货币市场基金':'mmf',
     }
 
+    # 资产基准
+    ASSET_BENCHMARK = {
+        'us_stock': 'RIY',      # 罗素1000指数
+        'us_bond': 'LUACTRUU',  # Bloomberg Barclays US Corporate Total Return Value Unhedged USD
+        'ap_stock': 'MXAP', # MSCI AC Asia ex Japan Net Total Return USD Index
+        'ap_bond': 'JPEIJACC',  # J.P. Morgan Asia Credit Index Core
+    }
+
     NOT_CONSIDER_TYPE = ['指数基金']
 
     def __init__(self, data_helper: RawDataHelper):
@@ -45,7 +53,7 @@ class OverseaFundNavAnalysis:
     def init(self, end_date=str):
         fund_info = self._raw_api.get_over_sea_fund_info()
         fund_benchmark = self._raw_api.get_over_sea_fund_benchmarks()
-        self.fund_info = pd.merge(fund_info, fund_benchmark[['benchmark_final','isin_code']], on='isin_code').set_index('codes')    
+        self.fund_info = pd.merge(fund_info, fund_benchmark[['benchmark_final','industry_1','industry_2','isin_code']], on='isin_code').set_index('codes')    
         self.fund_info = self.fund_info[~self.fund_info.fund_type.isin(self.NOT_CONSIDER_TYPE)]
         for fund_type, benchmark in self.DEFAULT_BENCHMARK.items():
             fund_list = self.fund_info[(self.fund_info['fund_type'] == fund_type) & (self.fund_info.benchmark_final.isnull())].index.tolist()
@@ -56,6 +64,47 @@ class OverseaFundNavAnalysis:
         self.fund_nav_adj = self.fund_nav_adj.pivot_table(index='datetime',columns='codes',values='nav').replace(0,np.nan).ffill()
         self.index_price = self._raw_api.get_oversea_index_price(end_date=end_date)        
         self.index_price = self.index_price.pivot_table(index='datetime',columns='codes',values='close').replace(0,np.nan).ffill()
+        self.get_new_fund_benchmark()
+
+    def get_new_fund_benchmark(self):
+        # 由于数据更新 当前把基金分四类设置基准
+        us_stock_fund_list = self.fund_info[(self.fund_info.area.isin(['环球','美国'])) 
+                      &(self.fund_info.industry_1 == 'Equity Fund')].index.tolist()
+        us_bond_fund_list = self.fund_info[(self.fund_info.area == '美国')&(self.fund_info.industry_1 == 'Debt Fund')].index.tolist()
+        ap_stock_fund_list = self.fund_info[((self.fund_info.area == '亚洲 (包括日本)')|(self.fund_info.area == '亚洲 (日本除外)'))&(self.fund_info.industry_1 == 'Equity Fund')].index.tolist()
+        ap_bond_fund_list = self.fund_info[((self.fund_info.area == '亚洲 (包括日本)')|(self.fund_info.area == '亚洲 (日本除外)')) & (self.fund_info.industry_1 == 'Debt Fund')].index.tolist()
+
+
+        l = us_stock_fund_list+us_bond_fund_list+ap_stock_fund_list+ap_bond_fund_list
+        fl = self.fund_info.index.tolist()
+        fls = [i for i in fl if i not in l]
+
+        _fund_info = self.fund_info.loc[fls]
+        cl = _fund_info[_fund_info.fund_type == '股票基金'].area.unique().tolist()
+        asian_country = ['泰国', '日本', '大中华', '新兴市场', '中国','新兴市场','中国A股','香港','印尼','台湾', '印度','印尼','中国及印度','越南', '菲律宾','前沿市場','马来西亚及新加坡','韩国',
+        '新加坡']
+        all_country = [i for i in cl if i not in asian_country]
+        ap_stock_fund_list.extend(_fund_info[(_fund_info.fund_type == '股票基金') & (_fund_info.area.isin(asian_country))].index.tolist())
+        us_stock_fund_list.extend(_fund_info[(_fund_info.fund_type == '股票基金') & (_fund_info.area.isin(all_country))].index.tolist())
+
+        cl = _fund_info[_fund_info.fund_type != '股票基金'].area.unique().tolist()
+        asian_country = ['中国A股','大中华','亚洲 (日本除外)','香港','新兴市场','中国','印度']
+        all_country = [i for i in cl if i not in asian_country]
+        us_bond_fund_list.extend(_fund_info[(_fund_info.fund_type != '股票基金') & (_fund_info.area.isin(all_country))].index.tolist())
+        ap_bond_fund_list.extend(_fund_info[(_fund_info.fund_type != '股票基金') & (_fund_info.area.isin(asian_country))].index.tolist())
+
+        benchmark_dic = {
+            'us_stock':us_stock_fund_list,
+            'us_bond':us_bond_fund_list,
+            'ap_stock':ap_stock_fund_list,
+            'ap_bond':ap_bond_fund_list,
+        }
+        fund_benchmark = {}
+        for asset_id, fund_list in benchmark_dic.items():
+            for fund_id in fund_list:
+                fund_benchmark[fund_id] = asset_id
+        self.fund_benchmark_dic = fund_benchmark
+
 
     def get_update_date(self, df_new, df_old, dt_col='datetime'): # dt_col in other db maybe report_date
         codes_list = df_new.codes.unique().tolist()
@@ -93,16 +142,11 @@ class OverseaFundNavAnalysis:
     def process_fund_ret(self):
         failed_tasks: List[str] = []
         try:
-            _df = self.fund_nav.pct_change(1)
+            _df = self.fund_nav.pct_change(1).iloc[1:] * 100
             _df = pd.DataFrame(_df.stack())
             _df.columns=['ret']
             _df = _df.reset_index()
-            _df = _df[_df.datetime >= datetime.date(2021,1,1)]
-            end_date = self.fund_nav.index[-1]
-            existed_start_date = end_date - datetime.timedelta(days=30)
-            exsited_data = self._raw_api.get_oversea_fund_ret_daily(start_date = existed_start_date)
-            _df = self.get_update_date(df_new=_df, df_old=exsited_data, dt_col='datetime')
-            self._data_helper._upload_raw(_df, OSFundRet.__table__.name)
+            self._data_helper._upload_raw(_df, OSFundRet.__table__.name,to_truncate=True)
         except Exception as e:
             print(e)
             traceback.print_exc()
@@ -158,7 +202,9 @@ class OverseaFundNavAnalysis:
                     continue
                 fund_nav_i = self.fund_nav[[fund_id]]
                 fund_nav_adj_i = self.fund_nav_adj[[fund_id]]
-                benchmark_id = self.fund_info.loc[fund_id].benchmark_final
+                #benchmark_id = self.fund_info.loc[fund_id].benchmark_final
+                benchmark_id = self.ASSET_BENCHMARK[self.fund_benchmark_dic[fund_id]]
+                
                 if not benchmark_id in self.index_price or benchmark_id in ['USC0TR03','G0O1','I02885JP']:
                     benchmark_id = self.DEFAULT_BENCHMARK[self.fund_info.loc[fund_id,'fund_type']]
                 fund_nav_i = fund_nav_i.join(self.index_price[benchmark_id]).ffill().dropna()
@@ -179,7 +225,7 @@ class OverseaFundNavAnalysis:
                             risk_free_rate=0.015,
                             frequency='1M',
                             ret_method='pct_ret',
-                            benchmark_values=_fund_nav_i.benchmark.values,
+                            benchmark_values=_fund_nav_adj_i.benchmark.values,
                         )
                     res_i_d = CalculatorBase.get_stat_result(
                                     dates = _fund_nav_i.index.values,
@@ -203,7 +249,7 @@ class OverseaFundNavAnalysis:
             _df = pd.concat(res)
             _df = _df.drop(columns=['start_date']).rename(columns={'end_date':'datetime'})
             _df = _df.replace(np.Inf,np.nan).replace(-np.Inf,np.nan)
-            self._data_helper._upload_raw(_df, QSOverseaFundIndicator.__table__.name)
+            self._data_helper._upload_raw(_df, QSOverseaFundIndicator.__table__.name, to_truncate=True)
         except Exception as e:
             print(e)
             traceback.print_exc()
@@ -249,7 +295,7 @@ class OverseaFundNavAnalysis:
                 'total_score':int,
             }
             _df = _df.astype(type_dic)
-            self._data_helper._upload_raw(_df, QSOverseaFundRadarScore.__table__.name)
+            self._data_helper._upload_raw(_df, QSOverseaFundRadarScore.__table__.name, to_truncate=True)
         except Exception as e:
             print(e)
             traceback.print_exc()
