@@ -330,6 +330,7 @@ class OtherRawDataDownloader:
             'H0A0':'LG30TRUU',  
             'I02885JP':'I09585JP', 
             'USC0TR03':'LD08TRUU',
+            'I08273CN':'mmf',
         }
         df.benchmark_final = df.benchmark_final.replace(replace_dic)
         #df.to_sql('oversea_fund_benchmarks', RawDatabaseConnector().get_engine(), index=False, if_exists='append')
@@ -350,4 +351,4 @@ class OtherRawDataDownloader:
         df = df.reset_index()
         df = df.rename(columns={'level_1':'codes'})
         #df.to_sql('oversea_fund_nav_adj', RawDatabaseConnector().get_engine(), index=False, if_exists='append')
-        self._data_helper._upload_raw(df, OSFundNavAdj.__table__.name)
\ No newline at end of file
+        self._data_helper._upload_raw(df, OSFundNavAdj.__table__.name, to_truncate=True)
\ No newline at end of file
