@@ -957,6 +957,19 @@ class Calculator:
                 df[col] = (df[col] * 100).round(2)
         df['夏普比率'] = df['夏普比率'].round(2)
         return df
+        
+    @staticmethod
+    def get_product_stats(df:pandas.DataFrame, asset_info: pandas.DataFrame):
+        df = Calculator.get_asset_stats(df, asset_info)
+        df = df.rename(columns={'具体指数':'产品'}).drop(columns=['类别'])
+        name_dic = {}
+        for r in asset_info.itertuples():
+            if '典型产品' == r.asset_type:
+                name_dic[r.real_name] = r.asset_name
+            else:
+                name_dic[r.real_name] = r.asset_type
+        df.loc[:,'策略类型'] = df.产品.map(name_dic)
+        return df
 
     @staticmethod
     def get_asset_corr(df:pandas.DataFrame, period='week'):#'month'
