@@ -102,7 +102,8 @@ class CalculatorBase:
         annual_ret = monthly_ret.rolling(window=window).apply(lambda x : x.sum() * yearly_multiplier - risk_free_rate)
         annual_vol = monthly_ret.rolling(window=window).apply(lambda x : x.std(ddof=1) * np.sqrt(period_num))
         sharpe = (annual_ret / annual_vol)
-        sharpe = sharpe.replace(np.Inf, np.nan).replace(-np.Inf, sharpe).dropna() # 空值sharpe赋值np.nan
+        dic = {np.Inf:np.nan,-np.Inf:np.nan}
+        sharpe = sharpe.replace(dic).dropna()
         if sharpe.shape[0] < 6:
             return np.nan
         mod = AutoReg(endog=sharpe.values, lags=1)
@@ -445,6 +446,7 @@ class CalculatorBase:
                 sr_ret = sr_ret.reindex(_index)
                 sr_benchmark_ret = sr_benchmark_ret.reindex(_index)
                 win_rate = np.mean((sr_ret > sr_benchmark_ret) * 1)
+                win_rate_0 = np.mean((sr_ret > 0) * 1)
                 corr = sr_ret.corr(sr_benchmark_ret)    
                 track_err = (sr_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(period_1y)
                 info = excess_ret / track_err
@@ -480,6 +482,22 @@ class CalculatorBase:
                     mod = AutoReg(endog=df_ret.excess_ret.values, lags=1)
                     res = mod.fit()
                     excess_ret_cotinue = res.params[0]
+
+                sr_excess_value = np.exp((sr_ret-sr_benchmark_ret).cumsum())
+                _b_d = sr.loc[:sr_excess_value.index[0]].index[-2]
+                sr_excess_value.loc[_b_d] = 1
+                sr_excess_value = sr_excess_value.sort_index()
+                mdd_part =  sr_excess_value / sr_excess_value.rolling(window=sr_excess_value.shape[0], min_periods=1).max()
+                excess_mdd = 1 - mdd_part.min()
+                if np.isnan(excess_mdd):
+                    excess_mdd_date2 = None
+                    excess_mdd_date1 = None
+                    excess_mdd_lens = None
+                else:
+                    excess_mdd_date2 = mdd_part.idxmin()
+                    excess_mdd_date1 = sr[:excess_mdd_date2].idxmax()
+                    excess_mdd_lens = (excess_mdd_date2-excess_mdd_date1).days
+                
                 return {
                     'start_date':start_date,
                     'end_date':end_date,
@@ -522,6 +540,7 @@ class CalculatorBase:
                     'beta_hm':beta_hm,
                     'excess_ret':excess_ret,
                     'win_rate':win_rate,
+                    'win_rate_0':win_rate_0,
                     'corr':corr,
                     'track_err':track_err,
                     'info':info,
@@ -534,6 +553,10 @@ class CalculatorBase:
                     'down_capture':down_capture,
                     'excess_ret_cotinue':excess_ret_cotinue,
                     'continue_value_m':continue_value_m,
+                    'excess_mdd':excess_mdd,
+                    'excess_mdd_date1':excess_mdd_date1,
+                    'excess_mdd_date2':excess_mdd_date2,
+                    'excess_mdd_lens':excess_mdd_lens,
                 }
             else:
                 return {
@@ -616,6 +639,7 @@ class CalculatorBase:
                     'beta_hm':0,
                     'excess_ret':0,
                     'win_rate':0,
+                    'win_rate_0':0,
                     'corr':0,
                     'track_err':0,
                     'info':0,
@@ -628,6 +652,10 @@ class CalculatorBase:
                     'down_capture':0,
                     'excess_ret_cotinue':0,
                     'continue_value_m':0,
+                    'excess_mdd':0,
+                    'excess_mdd_date1':dates[0] if len(dates) > 0 else None,
+                    'excess_mdd_date2':dates[0] if len(dates) > 0 else None,
+                    'excess_mdd_lens':0,
                 }
 
     @staticmethod
